<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>Application</name>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="50"/>
        <source>Cooperation</source>
        <translation>Kerjasama</translation>
    </message>
    <message>
        <location filename="../../src/apps/dde-cooperation/main.cpp" line="54"/>
        <source>Cooperation is a powerful cross-terminal office tool that helps you deliver files, share keys and mice, and share clipboards between different devices.</source>
        <translation>Kerjasama adalah alat pekerjaan kantor yang kuat dan lintas-terminal yang membantu Anda mengirimkan fail, membagi keyboard dan mouse, serta membagi clipboard antara perangkat yang berbeda.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="69"/>
        <source>File transfer settings</source>
        <translation>Pengaturan pengiriman fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="71"/>
        <source>Settings</source>
        <comment>button</comment>
        <translation>Pengaturan</translation>
    </message>
</context>
<context>
    <name>cooperation_core::BottomLabel</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="341"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="373"/>
        <source>Local IP: %1</source>
        <translation>IP Lokal: %1</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="25"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; mengirimkan beberapa fail kepada Anda</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="34"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Tolak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="35"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Terima</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationSearchEdit</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/cooperationsearchedit.cpp" line="34"/>
        <source>Search</source>
        <translation>Cari</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTaskDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="111"/>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="131"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="134"/>
        <source>Retry</source>
        <comment>button</comment>
        <translation>Coba lagi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="157"/>
        <source>Reject</source>
        <comment>button</comment>
        <translation>Tolak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="160"/>
        <source>Accept</source>
        <comment>button</comment>
        <translation>Terima</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationtaskdialog.cpp" line="184"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Tutup</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationTransDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="275"/>
        <source>File Transfer</source>
        <translation>Pengiriman Fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="278"/>
        <source>File transfer</source>
        <translation>Pengiriman fail</translation>
    </message>
</context>
<context>
    <name>cooperation_core::CooperationUtil</name>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="217"/>
        <source>View Help Manual</source>
        <translation>Lihat Panduan Bantuan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="218"/>
        <source>Welcome to dde-cooperation</source>
        <translation>Selamat datang di dde-cooperation</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>Keyboard and mouse sharing</source>
        <translation>Pembagian keyboard dan mouse</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="222"/>
        <source>When a connection is made between two devices, the initiator&apos;s keyboard and mouse can be used to control the other device</source>
        <translation>Apabila terdapat koneksi antara dua perangkat, keyboard dan mouse pihak yang memulai dapat digunakan untuk mengendalikan perangkat lainnya.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Clipboard sharing</source>
        <translation>Pembagian clipboard</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="224"/>
        <source>Once a connection is made between two devices, the clipboard will be shared and can be copied on one device and pasted on the other device</source>
        <translation>Setelah terdapat koneksi antara dua perangkat, clipboard akan dibagikan dan dapat dicopy di satu perangkat serta pasted di perangkat lainnya.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>Delivery of documents</source>
        <translation>Pengiriman dokumen</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="226"/>
        <source>After connecting between two devices, you can initiate a file delivery to the other device</source>
        <translation>Setelah terdapat koneksi antara dua perangkat, Anda dapat memulai pengiriman fail ke perangkat lainnya.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>For detailed instructions, please click on the Help Manual below</source>
        <translation>Untuk instruksi terperinci, silakan klik Panduan Bantuan di bawah ini.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/utils/cooperationutil.cpp" line="228"/>
        <source>Usage</source>
        <translation>Penggunaan</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DeviceItem</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="191"/>
        <source>connected</source>
        <translation>terhubung</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="197"/>
        <source>connectable</source>
        <translation>dapat terhubung</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/deviceitem.cpp" line="204"/>
        <source>offline</source>
        <translation>offline</translation>
    </message>
</context>
<context>
    <name>cooperation_core::DiscoverController</name>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="245"/>
        <source>Confirm</source>
        <translation>Konfirmasi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="246"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="248"/>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="257"/>
        <source>Please click to confirm to enable the LAN discovery service!</source>
        <translation>Sila klik untuk mengesahkan untuk membolehkan perkhidmatan pemeriksaan LAN!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="249"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned on</source>
        <translation>Tidak dapat mendeteksi dan ditemukan oleh peranti lain apabila perkhidmatan pemeriksaan LAN tidak dinyalakkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/discover/discovercontroller.cpp" line="258"/>
        <source>Unable to discover and be discovered by other devices when LAN discovery service is not turned onRight click on Windows Start menu -&gt;Computer Management -&gt;Services and Applications -&gt;Services to enable Bonjour service</source>
        <translation>Tidak dapat mendeteksi dan ditemukan oleh peranti lain apabila perkhidmatan pemeriksaan LAN tidak dinyalakkan. Klik kanan pada menu Mulai Windows -&gt; Pengurusan Komputer -&gt; Perkhidmatan dan Aplikasi -&gt; Perkhidmatan untuk mengaktifkan perkhidmatan Bonjour</translation>
    </message>
</context>
<context>
    <name>cooperation_core::FirstTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="126"/>
        <source>First step</source>
        <translation>Langkah pertama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="127"/>
        <source>The opposite end opens the application and connects to the same network</source>
        <translation>Pihak berlawan membuka aplikasi dan menyambung ke jaringan yang sama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="128"/>
        <source>Second step</source>
        <translation>Langkah kedua</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="130"/>
        <source>Third step</source>
        <translation>Langkah ketiga</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="189"/>
        <source>to send the file</source>
        <translation>untuk menghantar fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="196"/>
        <source>to connect to the peer device</source>
        <translation>untuk menyambung ke peranti pasangan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="129"/>
        <source>Enter the peer IP in the search box</source>
        <translation>Masukkan IP pasangan dalam kotak carian</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/firsttipwidget.cpp" line="131"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
</context>
<context>
    <name>cooperation_core::InformationDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="153"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="158"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="166"/>
        <source>the file save location is invalid</source>
        <translation>lokasi penyimpanan fail tidak sah</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/filechooseredit.cpp" line="172"/>
        <source>This path is a read-only directory. Please choose a different location for saving the file.</source>
        <translation>Laluan ini adalah direktori baca sahaja. Sila pilih lokasi lain untuk menyimpan fail.</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LockScreenWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="204"/>
        <source>The current device has been locked</source>
        <translation>Peranti semasa telah dikunci</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/screenmirroringwindow.cpp" line="207"/>
        <source>You can unlock it on mobile devices</source>
        <translation>Anda boleh membuka kunci peranti ini pada peranti mudah alih</translation>
    </message>
</context>
<context>
    <name>cooperation_core::LookingForDeviceWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="81"/>
        <source>Looking for devices</source>
        <translation>Mencari peranti</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindow</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="266"/>
        <source>Minimise to system tray</source>
        <translation>Kurangkan ke tray sistem</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="268"/>
        <source>Exit</source>
        <translation>Keluar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="277"/>
        <source>No more enquiries</source>
        <translation>Tiada soalan lagi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="285"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="296"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="286"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="295"/>
        <source>Confirm</source>
        <translation>Kesahkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="287"/>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="294"/>
        <source>Please select your operation</source>
        <translation>Sila pilih operasi anda</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="338"/>
        <source>Restore</source>
        <translation>Pulihkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/mainwindow.cpp" line="339"/>
        <source>Quit</source>
        <translation>Keluar</translation>
    </message>
</context>
<context>
    <name>cooperation_core::MainWindowPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="62"/>
        <source>Computer</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="63"/>
        <source>Phone</source>
        <translation>Telefon</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="74"/>
        <source>Selection of delivery device</source>
        <translation>Pemilihan peranti penghantaran</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="84"/>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="126"/>
        <source>Settings</source>
        <translation>Pengaturan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/linux/mainwindow_p_linux.cpp" line="88"/>
        <source>Download client</source>
        <translation>Muat turun pemandu</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/win/mainwindow_p_win.cpp" line="130"/>
        <source>Download Windows client</source>
        <translation>Muat turun pemandu Windows</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoNetworkWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="150"/>
        <source>Please connect to the network</source>
        <translation>Sila hubungkan ke rangkaian</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultTipWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="185"/>
        <source>1. Enable cross-end collaborative applications. Applications on the UOS can be downloaded from the App Store, and applications on the Windows side can be downloaded from: </source>
        <translation>1. Aktifkan aplikasi kolaboratif lintas peranti. Aplikasi pada UOS boleh dimuat turun daripada Stor Aplikasi, dan aplikasi pada pihak Windows boleh dimuat turun daripada:</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="199"/>
        <source>2. On the same LAN as the device</source>
        <translation>2. Di dalam rangkaian LAN yang sama dengan peranti</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="204"/>
        <source>3. File Manager-Settings-File Drop-Allow the following users to drop files to me -&quot;Everyone on the same LAN&quot;</source>
        <translation>3. Pengurus Fail-Preferensi-Penghantar Fail-Permbolehan pengguna berikut menghantar fail kepada saya -&quot;Semua dalam LAN yang sama&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="206"/>
        <source>3. Settings-Basic Settings-Discovery Mode-&quot;Allow everyone in the same LAN&quot;</source>
        <translation>3. Preferensi-Preferensi Asas-Modo Pemetaan-&quot;Permbolehan semua dalam LAN yang sama&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="212"/>
        <source>4. Try entering the target device IP in the top search box</source>
        <translation>4. Cuba masukkan IP peranti sasaran dalam kotak carian paling atas</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="216"/>
        <source>Unable to find collaborative device？</source>
        <translation>Tidak dapat mencari peranti kolaboratif?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="245"/>
        <source>1. The mobile phone needs to download cross end collaborative applications.</source>
        <translation>1. Telefon bimbit perlu memuat turun aplikasi kolaboratif lintas peranti.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="246"/>
        <source>Go to download&gt;</source>
        <translation>Pergi muat turun&gt;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="250"/>
        <source>2. After installation, scan the code to connect to this device for collaboration.</source>
        <translation>2. Selepas pemasangan, imbas kod untuk menghubungkan ke peranti ini untuk kolaborasi.</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="251"/>
        <source>3. After connecting this device, the mobile end needs to keep cross end collaborative applications open and on the same LAN as this device</source>
        <translation>3. Selepas menghubungkan peranti ini, pihak bimbit perlu mengekalkan aplikasi kolaboratif lintas peranti yang terbuka dan dalam LAN yang sama dengan peranti ini</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="253"/>
        <source>Instructions for use</source>
        <translation>Arahan penggunaan</translation>
    </message>
</context>
<context>
    <name>cooperation_core::NoResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/cooperationstatewidget.cpp" line="293"/>
        <source>No device found</source>
        <translation>Tiada peranti ditemukan</translation>
    </message>
</context>
<context>
    <name>cooperation_core::PhoneHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="65"/>
        <source>Disconnect</source>
        <translation>Putuskan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="93"/>
        <source>“%1”apply to initiate screen casting</source>
        <translation>“%1”diterapkan untuk memulakan screen casting</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="95"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="212"/>
        <source>cancel</source>
        <translation>batalkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="96"/>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="157"/>
        <source>comfirm</source>
        <translation>pastikan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="139"/>
        <source>“%1”connection disconnected!</source>
        <translation>“%1”koneksinya telah diputuskan!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="210"/>
        <source>Are you sure to disconnect and collaborate with &apos;%1&apos;?</source>
        <translation>Adakah anda pasti untuk memutuskan dan bekerjasama dengan &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/phonehelper.cpp" line="213"/>
        <source>disconnect</source>
        <translation>putuskan</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ProgressWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="115"/>
        <source>Remaining time %1 | %2%</source>
        <translation>Masa yang tinggal %1 | %2%</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="133"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Batal</translation>
    </message>
</context>
<context>
    <name>cooperation_core::QRCodeWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="102"/>
        <source>Scan code connection</source>
        <translation>Koneksikan kod imbas</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="108"/>
        <source>Please use the cross end collaboration app to scan the code</source>
        <translation>Sila gunakan aplikasi kolaborasi lintas peranti untuk imbas kod</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="114"/>
        <source>Mobile phones and devices need to be connected to the same local area network</source>
        <translation>Telefon bimbit dan peranti perlu dihubungkan ke rangkaian kawasan tempatan yang sama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/phonewidget.cpp" line="147"/>
        <source>Click to download UOS assistant APP</source>
        <translation>Klik untuk memuat turun APLIKASI Pemandu UOS</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ResultWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="179"/>
        <source>Ok</source>
        <comment>button</comment>
        <translation>Okay</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="182"/>
        <source>View</source>
        <comment>button</comment>
        <translation>Lihat</translation>
    </message>
</context>
<context>
    <name>cooperation_core::SettingDialogPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="47"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="53"/>
        <source>Everyone in the same LAN</source>
        <translation>Semua orang dalam jaringan LAN yang sama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="49"/>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="55"/>
        <source>Not allow</source>
        <translation>Tidak diperbolehkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="50"/>
        <source>Screen right</source>
        <translation>Kanan layar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="51"/>
        <source>Screen left</source>
        <translation>Kiri layar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="54"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Hanya mereka yang sedang berkolaborasi yang diperbolehkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="132"/>
        <source>Basic Settings</source>
        <translation>Pengaturan Dasar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="143"/>
        <source>Discovery mode</source>
        <translation>Mode Pemindaian</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="145"/>
        <source>Other devices can discover and connect with you through the &quot;Cooperation&quot; app</source>
        <translation>Perangkat lain dapat menemukan dan terhubung dengan Anda melalui aplikasi &quot;Cooperation&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="195"/>
        <source>Device name</source>
        <translation>Nama perangkat</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="213"/>
        <source>Peripheral share</source>
        <translation>Pembagian periferal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="215"/>
        <source>Allows peripherals that have been established to collaborate across devices to control this device, including keyboard, mouse, trackpad, etc</source>
        <translation>Memungkinkan periferal yang telah terhubung untuk berkolaborasi antar perangkat mengendalikan perangkat ini, termasuk keyboard, mouse, trackpad, dll</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="224"/>
        <source>When this device is the connected party, the mouse penetrates from the screen of this device to the position of the connected party</source>
        <translation>Ketika perangkat ini adalah pihak yang terhubung, mouse akan melewati layar perangkat ini ke posisi pihak yang terhubung</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="254"/>
        <source>Connection direction</source>
        <translation>Arah koneksi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="273"/>
        <source>Allows the following users to send files to me</source>
        <translation>Memungkinkan pengguna berikut mengirimkan file ke saya</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="280"/>
        <source>File save location</source>
        <translation>Lokasi penyimpanan file</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="296"/>
        <source>Share clipboard</source>
        <translation>Bagikan clipboard</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="298"/>
        <source>When sharing is enabled on the server (the connected device), the clipboard will be shared between the two computers</source>
        <translation>Ketika pembagian diaktifkan pada server (perangkat yang terhubung), clipboard akan dibagikan antara dua komputer</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="355"/>
        <source>The device name must contain 1 to 20 characters</source>
        <translation>Nama perangkat harus berisi 1 hingga 20 karakter</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/dialogs/settingdialog.cpp" line="362"/>
        <source>The device name must contain 1 to 63 characters</source>
        <translation>Nama perangkat harus berisi 1 hingga 63 karakter</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="238"/>
        <source>connect</source>
        <translation>Sambungkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="246"/>
        <source>Disconnect</source>
        <translation>Putuskan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="263"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="392"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="448"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="511"/>
        <source>Unable to collaborate to &quot;%1&quot;</source>
        <translation>Tidak dapat berkolaborasi dengan &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="265"/>
        <source>You are connecting to another device</source>
        <translation>Anda sedang menghubungi perangkat lain</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="280"/>
        <source>Requesting collaborate to &quot;%1&quot;</source>
        <translation>Mengajukan kerja sama dengan &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="307"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="483"/>
        <source>Coordination with &quot;%1&quot; has ended</source>
        <translation>Koordinasi dengan &quot;%1&quot; telah berakhir</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="353"/>
        <source>A cross-end collaboration request was received from &quot;%1&quot;</source>
        <translation>Permintaan kerja sama lintas perangkat diterima dari &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="354"/>
        <source>Reject</source>
        <translation>Tolak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="355"/>
        <source>Accept</source>
        <translation>Terima</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="374"/>
        <source>Cooperation</source>
        <translation>Kerja Sama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="393"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Koneksi ke &quot;%1&quot; gagal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="418"/>
        <source>Unable to collaborate</source>
        <translation>Tidak dapat berkolaborasi</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="419"/>
        <source>Failed to run process!</source>
        <translation>Proses gagal dijalankan!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="441"/>
        <source>Connection successful, coordinating with  &quot;%1&quot;</source>
        <translation>Koneksi berjaya, sedang berkoordinasi dengan &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="449"/>
        <source>&quot;%1&quot; has rejected your request for collaboration</source>
        <translation>&quot;%1&quot; menolak permintaan kolaborasi anda</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="459"/>
        <source>&quot;%1&quot; is connecting with other devices</source>
        <translation>&quot;%1&quot; sedang menghubungi peranti lain</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="503"/>
        <source>The connection request sent to you by &quot;%1&quot; was interrupted due to a timeout</source>
        <translation>Permintaan koneksi yang dikirimkan kepada anda oleh &quot;%1&quot; terganggu kerana timeout</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="513"/>
        <source>The other party does not confirm, please try again later</source>
        <translation>Pihak lain tidak mengesahkan, sila cuba lagi kemudian</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="524"/>
        <source>The other party has cancelled the connection request !</source>
        <translation>Pihak lain telah membatalkan permintaan koneksi ! </translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="528"/>
        <source>connect failed</source>
        <translation>konek gagal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="538"/>
        <source>Network not connected, file delivery failed this time.                               Please connect to the network and try again!</source>
        <translation>Rangkaian tidak terhubung, penghantaran fail gagal kali ini. Sila hubungkan ke rangkaian dan cuba lagi!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="545"/>
        <source>File transfer failed</source>
        <translation>Penghantaran fail gagal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="547"/>
        <source>Network not connected, file delivery failed this time.                                           Please connect to the network and try again!</source>
        <translation>Rangkaian tidak terhubung, penghantaran fail gagal kali ini. Sila hubungkan ke rangkaian dan cuba lagi!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="562"/>
        <source>Network exception</source>
        <translation>Kesalahan rangkaian</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="563"/>
        <source>Please check the network &quot;%1&quot;</source>
        <translation>Sila semak rangkaian &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::ShareHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="103"/>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="109"/>
        <source>Cooperation</source>
        <translation>Kerjasama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/sharehelper.cpp" line="200"/>
        <source>Connection successful, coordinating with &quot;%1&quot;</source>
        <translation>Koneksi berjaya, sedang berkoordinasi dengan &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="433"/>
        <source>Connect to &quot;%1&quot; failed</source>
        <translation>Konek ke &quot;%1&quot; gagal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="458"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="609"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="683"/>
        <source>File read/write exception</source>
        <translation>Kesalahan membaca/tulis fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="579"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="630"/>
        <source>The other party has canceled the file transfer</source>
        <translation>Pihak lain telah membatalkan penghantaran fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="478"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="626"/>
        <source>File sent successfully</source>
        <translation>Fail berjaya dihantar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="168"/>
        <source>View transfer history</source>
        <translation>Lihat sejarah penghantaran</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="177"/>
        <source>Send files</source>
        <translation>Hantar fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="302"/>
        <source>The other party did not receive, the files failed to send</source>
        <translation>Pihak lain tidak menerima, fail gagal dihantar</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="332"/>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="335"/>
        <source>File receiving %1% | Remaining time %2</source>
        <translation>Menerima fail %1% | Masa tinggal %2</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Sending files to &quot;%1&quot;</source>
        <translation>Menghantar fail ke &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="342"/>
        <source>Receiving files from &quot;%1&quot;</source>
        <translation>Menerima fail dari &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="399"/>
        <source>Reject</source>
        <translation>Tolak</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="400"/>
        <source>Accept</source>
        <translation>Terima</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="401"/>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="394"/>
        <source>&quot;%1&quot; send some files to you</source>
        <translation>&quot;%1&quot; menghantar fail kepada anda</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="313"/>
        <source>View</source>
        <translation>Tengok</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="412"/>
        <source>The other party has cancelled the transfer request !</source>
        <translation>Pihak lain telah membatalkan permintaan penghantaran !</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="452"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="605"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="680"/>
        <source>Insufficient storage space, file delivery failed this time. Please clean up disk space and try again!</source>
        <translation>&gt;-
 Ruang penyimpanan tidak mencukupi, penghantaran fail gagal kali ini. Sila kosongkan
 ruang hard disk dan cuba lagi!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="455"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="607"/>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="677"/>
        <source>Network not connected, file delivery failed this time. Please connect to the network and try again!</source>
        <translation>&gt;-
 Tidak ada sambungan ke rangkaian, penghantaran fail gagal kali ini. Sila sambung ke
 rangkaian dan cuba lagi!</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="554"/>
        <source>calculating</source>
        <translation>mengira</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="563"/>
        <source>The other party rejects your request</source>
        <translation>Pihak lain menolak permintaan anda</translation>
    </message>
</context>
<context>
    <name>cooperation_core::TransferHelperPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/transferhelper.cpp" line="132"/>
        <source>File transfer</source>
        <translation>Penghantaran fail</translation>
    </message>
</context>
<context>
    <name>cooperation_core::VncViewer</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="211"/>
        <location filename="../../src/lib/cooperation/core/gui/phone/vncviewer.cpp" line="213"/>
        <source>Disconnected</source>
        <translation>Tidak berhubung</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WaitConfirmWidget</name>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="75"/>
        <source>File Transfer</source>
        <translation>Penghantaran fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/net/helper/dialogs/cooperationdialog.cpp" line="91"/>
        <source>Wait for confirmation...</source>
        <translation>Menunggu pengesahan...</translation>
    </message>
</context>
<context>
    <name>cooperation_core::WorkspaceWidgetPrivate</name>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="52"/>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="53"/>
        <source>Please enter the device ip/name of the collaborator</source>
        <translation>Sila masukkan alamat IP/peranti nama rakan kerja</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="56"/>
        <source>Nearby Device</source>
        <translation>Peranti Berdekatan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/core/gui/widgets/workspacewidget.cpp" line="72"/>
        <source>Re-scan for devices</source>
        <translation>Skena semula untuk peranti</translation>
    </message>
</context>
<context>
    <name>cooperation_transfer::TransferHelper</name>
    <message>
        <location filename="../../src/lib/cooperation/transfer/helper/transferhelper.cpp" line="105"/>
        <source>Send files</source>
        <translation>Hantar fail</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationMenuScene</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/menu/cooperationmenuscene.cpp" line="34"/>
        <source>File transfer</source>
        <translation>Penghantaran fail</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::CooperationPlugin</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/cooperationplugin.cpp" line="64"/>
        <source>File transfer</source>
        <translation>Penghantaran fail</translation>
    </message>
</context>
<context>
    <name>dfmplugin_cooperation::FileTransferSettingsDialog</name>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="154"/>
        <source>File transfer settings</source>
        <translation>Pengesahan penghantaran fail</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="171"/>
        <source>Everyone in the same LAN</source>
        <translation>Semua orang dalam jaringan LAN yang sama</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="172"/>
        <source>Only those who are collaborating are allowed</source>
        <translation>Hanya mereka yang sedang berkolaborasi yang dibenarkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="173"/>
        <source>Not allow</source>
        <translation>Tidak dibenarkan</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="178"/>
        <source>Allows the following users to send files to me</source>
        <translation>Mengizinkan pengguna berikut menghantar fail kepada saya</translation>
    </message>
    <message>
        <location filename="../../src/lib/cooperation/dfmplugin/dialogs/filetransfersettingsdialog.cpp" line="179"/>
        <source>File save location</source>
        <translation>Lokasi penyimpanan fail</translation>
    </message>
</context>
</TS>